# --------------------------------------------------------------------------
#
# Esvon Classifieds v.4.0
# Copyright(C), Esvon LTD, 2001-2010, All Rights Reserved.
# E-mail: products@esvon.com
#
# All forms of reproduction, including, but not limited to, internet posting, 
# printing, e-mailing, faxing and recording are strictly prohibited.
# One license required per site running Esvon Classifieds. 
# To obtain a license for using Esvon Classifieds, please register at
# http://www.esvon.com/pg/products/p_classifieds/
#
# --------------------------------------------------------------------------


CREATE TABLE admin_login (
   id smallint(5) unsigned NOT NULL auto_increment,
   ip varchar(255) NOT NULL,
   ldate datetime NOT NULL,
   login_used varchar(50) NOT NULL,
   status char(1) NOT NULL,
   PRIMARY KEY (id)
);

CREATE TABLE ip (
   ip int(11) unsigned NOT NULL,
   link_id mediumint(8) unsigned NOT NULL,
   type char(1) NOT NULL,
   bdate datetime NOT NULL,
   PRIMARY KEY (ip, link_id, type)
);


CREATE TABLE category (
   id mediumint(8) unsigned NOT NULL auto_increment,
   name varchar(100) NOT NULL,
   pid mediumint(8) unsigned NOT NULL,
   fset varchar(255) NOT NULL,
   weight smallint(5) unsigned DEFAULT '0' NOT NULL,
   disabled tinyint(3) unsigned NOT NULL,
   image varchar(255) NOT NULL,
   image_alt varchar(255) NOT NULL,
   se_url varchar(255) NOT NULL,
   descr text NOT NULL,
   meta_k text NOT NULL,
   meta_d text NOT NULL,
   PRIMARY KEY (id),
   KEY pid (pid),
   KEY fset (fset),
   KEY name ( name(5) )
);

CREATE TABLE expense (
   id int(11) unsigned NOT NULL auto_increment,
   cdate date DEFAULT '0000-00-00' NOT NULL,
   amount decimal(10,2) DEFAULT '0.00' NOT NULL,
   descr varchar(255) NOT NULL,
   PRIMARY KEY (id)
);

CREATE TABLE extra_opt (
   id smallint(5) unsigned NOT NULL auto_increment,
   type varchar(10) NOT NULL,
   val varchar(10) NOT NULL,
   descr varchar(255) NOT NULL,
   price decimal(10,2) NOT NULL,
   active tinyint(1) NOT NULL,
   PRIMARY KEY (id),
   UNIQUE (type,val)
);

CREATE TABLE field (
   idx mediumint(8) unsigned NOT NULL auto_increment,
   fset varchar(30) NOT NULL,
   weight smallint(5) unsigned DEFAULT '0' NOT NULL,
   id varchar(40) NOT NULL,
   db_f varchar(40) NOT NULL,
   active tinyint(3) unsigned NOT NULL,
   required tinyint(3) unsigned NOT NULL,
   search_k tinyint(3) unsigned NOT NULL,
   editable char(1) NOT NULL,
   search varchar(255) NOT NULL,
   title varchar(255) NOT NULL,
   value text NOT NULL,
   type varchar(255) NOT NULL,
   extra text NOT NULL,
   size varchar(255) NOT NULL,
   min varchar(255) NOT NULL,
   max varchar(255) NOT NULL,
   input varchar(255) NOT NULL,
   chars varchar(255) NOT NULL, 
   err_msg text NOT NULL,
   attr varchar(255) NOT NULL,
   txt text NOT NULL,
   PRIMARY KEY (idx),
   UNIQUE(fset, id),
   UNIQUE(fset, db_f)
);

CREATE TABLE fset (
   id varchar(30) NOT NULL,
   descr text NOT NULL,
   PRIMARY KEY (id)
);

CREATE TABLE modules (
   id int(11) unsigned NOT NULL auto_increment,
   dir varchar(64) NOT NULL,
   name varchar(64) NOT NULL,
   descr text NOT NULL,
   admin_capable tinyint(1) DEFAULT '0' NOT NULL,
   user_capable tinyint(1) DEFAULT '0' NOT NULL,
   event_capable tinyint(1) DEFAULT '0' NOT NULL,
   block_capable tinyint(1) DEFAULT '0' NOT NULL,
   state char(1) DEFAULT 'U' NOT NULL,
   updated timestamp(14),
   PRIMARY KEY (id),
   UNIQUE dir (dir)
);

CREATE TABLE related_cat (
   related_id mediumint(8) unsigned DEFAULT '0' NOT NULL,
   id mediumint(8) unsigned DEFAULT '0' NOT NULL,
   PRIMARY KEY (related_id, id)
);

CREATE TABLE related_links (
   id int(11) unsigned NOT NULL auto_increment,
   catid mediumint(8) unsigned DEFAULT '0' NOT NULL,
   title varchar(255) NOT NULL,
   url varchar(255) NOT NULL,
   target varchar(20) NOT NULL,
   PRIMARY KEY (id),
   KEY catid (catid)
);

CREATE TABLE payment_log (
   id int(11) unsigned NOT NULL auto_increment,
   userid mediumint(8) unsigned DEFAULT '0' NOT NULL,
   link_id mediumint(8) unsigned NOT NULL default '0',
   cdate datetime NOT NULL,
   amount decimal(10,2) DEFAULT '0.00' NOT NULL,
   gross decimal(10,2) DEFAULT '0.00' NOT NULL,
   ip varchar(30) NOT NULL,
   txn_id varchar(255) NOT NULL,
   descr varchar(255) NOT NULL,
   PRIMARY KEY (id),
   KEY (userid),
   KEY (link_id)
);

CREATE TABLE payment_pending (
  id int(11) unsigned NOT NULL auto_increment,
  order_id mediumint(8) unsigned NOT NULL,
  details varchar(255) NOT NULL,
  amount decimal(10,2) NOT NULL default '0.00',
  odate datetime NOT NULL,
  userid mediumint(8) unsigned NOT NULL,
  adid mediumint(8) unsigned NOT NULL,
  ttype varchar(255) NOT NULL,
  ip varchar(30) NOT NULL,
  ref_id varchar(255) NOT NULL,
  PRIMARY KEY (id),
  KEY (order_id),
  KEY (ref_id)
);


CREATE TABLE price_plan (
   id varchar(20) NOT NULL,
   name varchar(255) NOT NULL,
   weight smallint(5) unsigned DEFAULT '0' NOT NULL,
   descr text NOT NULL,
   type varchar(10) NOT NULL,
   fee decimal(10,2) DEFAULT '0.00' NOT NULL,
   exp_days smallint(5) unsigned DEFAULT '0' NOT NULL,
   enabled tinyint(3) unsigned DEFAULT '0' NOT NULL,
   options text NOT NULL,
   expire_ads tinyint(3) unsigned DEFAULT '0' NOT NULL,
   realm char(1) DEFAULT '0' NOT NULL,
   pp_exp_into varchar(20) NOT NULL,
   pp_url varchar(255) NOT NULL,
   pp_icon_url varchar(255) NOT NULL,
   PRIMARY KEY (id)
);

CREATE TABLE price_plan_category (
   cid mediumint(8) unsigned DEFAULT '0' NOT NULL,
   ppid varchar(20) NOT NULL,
   PRIMARY KEY (cid, ppid)
);

CREATE TABLE price_plan_user (
   fee_id varchar(20) NOT NULL,
   sub_id varchar(20) NOT NULL,
   PRIMARY KEY (fee_id, sub_id)
);

CREATE TABLE register (
   email varchar(60) NOT NULL,
   code varchar(20) NOT NULL,
   regdate datetime NOT NULL,
   data text NOT NULL,
   PRIMARY KEY (email)
);

CREATE TABLE reserved_field (
  name varchar(80) NOT NULL,
  tbl char(1) NOT NULL,
  PRIMARY KEY  (name,tbl)
);


INSERT INTO reserved_field VALUES 
('approved', 'A'),
('user_approved', 'A'),
('catid', 'A'),
('hw_added', 'A'),
('disabled', 'U'),
('email', 'U'),
('en_exp_modify', 'U'),
('exp_date', 'A'),
('exp_date', 'U'),
('free_ad_used', 'U'),
('hw_ads_max', 'U'),
('hw_color', 'A'),
('hw_pay_plan', 'A'),
('hw_pay_plan', 'U'),
('hw_sid', 'U'),
('hw_vis', 'A'),
('hw_weight', 'A'),
('id', 'U'),
('images', 'A'),
('images', 'U'),
('lastlogin', 'U'),
('lastlogin_ip', 'U'),
('lastlogin_failure', 'U'),
('lastlogin_token', 'U'),
('link_id', 'A'),
('num_votes', 'A'),
('hw_feat', 'A'),
('hw_sold', 'A'),
('pwd', 'U'),
('rating', 'A'),
('regdate', 'U'),
('txn_id', 'A'),
('txn_id', 'U'),
('hw_updated', 'A'),
('userid', 'A'),
('reg_ip', 'U'),
('ip', 'A'),
('search_txt', 'A'),
('username', 'U');


CREATE TABLE session(
   session_id char(32) NOT NULL,
   expires int NOT NULL,
   userid mediumint(8) unsigned NOT NULL,
   ip char(15) NOT NULL,
   x_forw varchar(255) NOT NULL,
   data text NOT NULL,
   PRIMARY KEY (session_id)
);

CREATE TABLE template (
   id smallint(5) unsigned NOT NULL auto_increment,
   fname varchar(40) NOT NULL,
   `mod` varchar(64) NOT NULL,
   `fset` varchar(40) NOT NULL,
   `data` text NOT NULL,
   PRIMARY KEY (id),
   UNIQUE (`fname`,`mod`,`fset`)
);

CREATE TABLE hw_settings (
   id varchar(20) NOT NULL,
   login varchar(20) NOT NULL,
   pwd varchar(32) NOT NULL,
   lastlogin_date datetime NOT NULL,
   lastlogin_failure datetime NOT NULL,
   lastlogin_token varchar(32) NOT NULL,
   options blob NOT NULL,
   settings blob NOT NULL,
   PRIMARY KEY (id)
);

CREATE TABLE user_online (
   id mediumint(8) unsigned NOT NULL auto_increment,
   accessdate datetime NOT NULL,
   last_pg varchar(255) NOT NULL,
   PRIMARY KEY (id)
);

CREATE TABLE hits (
   lid mediumint(8) unsigned NOT NULL,
   hits int(11) unsigned NOT NULL,
   PRIMARY KEY (lid)
);

CREATE TABLE ad (

   link_id mediumint(8) unsigned NOT NULL auto_increment,
   catid mediumint(8) unsigned DEFAULT '0' NOT NULL,
   userid mediumint(8) unsigned DEFAULT '0' NOT NULL,
   approved tinyint(3) unsigned DEFAULT '1' NOT NULL,
   user_approved tinyint(3) unsigned DEFAULT '1' NOT NULL,
   hw_feat tinyint(3) unsigned DEFAULT '0' NOT NULL,
   hw_weight tinyint(3) unsigned DEFAULT '0' NOT NULL,
   hw_vis varchar(20) NOT NULL,
   hw_color varchar(255) NOT NULL,
   hw_sold tinyint(3) unsigned NOT NULL,
   rating decimal(4,2) DEFAULT '0' NOT NULL,
   num_votes smallint(5) unsigned DEFAULT '0' NOT NULL,
   hw_added datetime NOT NULL,
   hw_updated datetime NOT NULL,
   exp_date datetime not null,
   ip varchar(30) NOT NULL,
   txn_id varchar(255) not null,
   hw_pay_plan text NOT NULL,
   v_title varchar(255) NOT NULL,
   v_zip varchar(255) NOT NULL,
   v_price decimal(10,2) DEFAULT '0' NOT NULL,

   v_255_1 varchar(255) NOT NULL,
   v_255_2 varchar(255) NOT NULL,
   v_255_3 varchar(255) NOT NULL,
   v_255_4 varchar(255) NOT NULL,
   v_255_5 varchar(255) NOT NULL,
   v_255_6 varchar(255) NOT NULL,
   v_255_7 varchar(255) NOT NULL,
   v_255_8 varchar(255) NOT NULL,
   v_255_9 varchar(255) NOT NULL,
   v_255_10 varchar(255) NOT NULL,
   v_255_11 varchar(255) NOT NULL,
   v_255_12 varchar(255) NOT NULL,
   v_255_13 varchar(255) NOT NULL,
   v_255_14 varchar(255) NOT NULL,
   v_255_15 varchar(255) NOT NULL,
   v_255_16 varchar(255) NOT NULL,
   v_255_17 varchar(255) NOT NULL,
   v_255_18 varchar(255) NOT NULL,
   v_255_19 varchar(255) NOT NULL,
   v_255_20 varchar(255) NOT NULL,
   v_255_21 varchar(255) NOT NULL,
   v_255_22 varchar(255) NOT NULL,
   v_255_23 varchar(255) NOT NULL,
   v_255_24 varchar(255) NOT NULL,
   v_255_25 varchar(255) NOT NULL,
   v_255_26 varchar(255) NOT NULL,
   v_255_27 varchar(255) NOT NULL,
   v_255_28 varchar(255) NOT NULL,
   text_1 mediumtext NOT NULL,
   text_2 mediumtext NOT NULL,
   int_1 int(11) DEFAULT '0' NOT NULL,
   int_2 int(11) DEFAULT '0' NOT NULL,
   int_3 int(11) DEFAULT '0' NOT NULL,

   images text not null,
   v_descr mediumtext NOT NULL,
   search_txt mediumtext NOT NULL,
   PRIMARY KEY (link_id),
   KEY (catid),
   KEY (userid),
   KEY (hw_feat),
   KEY (approved, user_approved, exp_date)
);

CREATE TABLE category_extra (
   cid mediumint(8) unsigned NOT NULL,
   type char(1) NOT NULL,
   PRIMARY KEY (cid, type)
);

CREATE TABLE file (
  lid mediumint(8) unsigned DEFAULT '0' NOT NULL,
  fname varchar(255) NOT NULL default '',
  descr text NOT NULL,
  approved tinyint(3) unsigned DEFAULT '1' NOT NULL,
  PRIMARY KEY (lid,fname)
); 

CREATE TABLE dep_menu (
   id smallint(5) unsigned NOT NULL auto_increment,
   pid tinyint(3) unsigned NOT NULL,
   name varchar(100) NOT NULL,
   PRIMARY KEY (id),
   UNIQUE (name)
);

CREATE TABLE dep_menu_tree (
   id mediumint(8) unsigned NOT NULL auto_increment,
   menu_id smallint(5) unsigned NOT NULL,
   pid mediumint(8) unsigned NOT NULL,
   name varchar(100) NOT NULL,
   weight smallint(5) unsigned DEFAULT '0' NOT NULL,
   PRIMARY KEY (id),
   KEY pid (pid),
   KEY (menu_id)
);

# --------------------------------------------------------
#
# Table structure for table 'user'
#

CREATE TABLE user (

   id mediumint(8) unsigned NOT NULL auto_increment,
   email varchar(60) NOT NULL,
   username varchar(60) NOT NULL,
   pwd varchar(20) NOT NULL,
   disabled tinyint(3) unsigned NOT NULL,
   en_exp_modify tinyint(3) unsigned not null,
   hw_sid varchar(32) NOT NULL,
   hw_ads_max smallint(5) unsigned NOT NULL,
   free_ad_used tinyint(3) unsigned not null,

   lastlogin datetime NOT NULL,
   lastlogin_ip varchar(255) NOT NULL,
   lastlogin_failure datetime NOT NULL,
   lastlogin_token varchar(32) NOT NULL,

   regdate datetime NOT NULL,
   reg_ip varchar(30) NOT NULL,
   exp_date datetime NOT NULL,
   txn_id varchar(255) NOT NULL,

   v_255_1 varchar(255) NOT NULL,
   v_255_2 varchar(255) NOT NULL,
   v_255_3 varchar(255) NOT NULL,
   v_255_4 varchar(255) NOT NULL,
   v_255_5 varchar(255) NOT NULL,
   v_255_6 varchar(255) NOT NULL,
   v_255_7 varchar(255) NOT NULL,
   v_255_8 varchar(255) NOT NULL,
   v_255_9 varchar(255) NOT NULL,
   v_255_10 varchar(255) NOT NULL,
   v_255_11 varchar(255) NOT NULL,
   v_255_12 varchar(255) NOT NULL,
   v_255_13 varchar(255) NOT NULL,
   v_255_14 varchar(255) NOT NULL,
   v_255_15 varchar(255) NOT NULL,

   hw_pay_plan text NOT NULL,
   images text not null,
   hw_opts text NOT NULL,
   PRIMARY KEY (id),
   UNIQUE (email),
   UNIQUE (username)
);

ALTER TABLE ad ADD FULLTEXT search_txt (v_title,v_descr,search_txt);

INSERT INTO hw_settings (id,login,pwd,options,settings) VALUES ('hw', 'adm', MD5('adm'), '', '');

INSERT INTO price_plan VALUES 
( 'SUB_FREE', 'Free Membership', 0, 'Used for all users when site is not in paid membership mode', 'SUB', '0.00', '30', '1', '[U_IM-Y][U_BROWSE_CATS-Y][U_POST_ADS-Y][U_LIST_ADS-Y][U_VIEW_AD_DET-Y]', '0', '', '', '', ''),
( 'FEE_FREE', 'Free Listing', 0, 'Used for all ads when site is not in paid posting mode', 'FEE', '0.00', '30', '1', '', '0', '', '', '', '');

INSERT INTO extra_opt VALUES 
(1, 'FEAT', '', 'No featuring', '0.00', '1'),
(2, 'FEAT', '1', 'Feature my ad', '30.00', '1'),
(3, 'VIS', '', 'No extra visibility for my ad', '0.00', '1'),
(4, 'VIS', 'B', 'Bold my ad', '4.00', '1'),
(5, 'VIS', 'BR', 'Bold and Red my ad', '8.00', '1'),
(6, 'WEIGHT', '', 'No priority', '0.00', '1'),
(7, 'WEIGHT', '1', 'Bronze Level Priority', '6.00', '1'),
(8, 'WEIGHT', '2', 'Silver Level Priority', '10.00', '1'),
(9, 'WEIGHT', '3', 'Gold Level Priority', '15.00', '1'),
(10, 'WEIGHT', '4', 'Platinum Level Priority', '25.00', '1'),
(11, 'COLOR', '', 'No extra highlight for my ad', '0.00', '1'),
(12, 'COLOR', 'FFFF00', 'Yellow highlight', '15.00', '1');

INSERT INTO fset (id, descr) VALUES 
('auto', ''),
('general', ''),
('job', ''),
('personals', ''),
('property', ''),
('{user_fields}', '');

INSERT INTO field (idx, fset, weight, id, db_f, active, required, search_k, search, title, value, type, extra, size, min, max, input, chars, err_msg, txt) VALUES 
(1, 'auto', 1, 'f_title', 'v_title', 1, 1, 0, '', 'Title', '', 'text', '', '40', '', '', '', '', '', ''),
(2, 'auto', 2, 'f_style', 'v_255_1', 1, 1, 0, 'Multi', 'Style', '', 'menu', 'Two-Door Coupe\nFour-Door Sedan\nHatchback\nConvertible\nMinivan/Van\nSport/Utility\nTruck\nATV\nMotorcyle\nRV\nScooters\nSnowmobile', '', '', '', '', '', '', ''),
(3, 'auto', 3, 'f_saletype', 'v_255_2', 1, 0, 0, '', 'Sale Type', '', 'menu', 'Used by Dealer\nNew by Dealer\nPrivate Party', '', '', '', '', '', '', 'Is this item for sale by an individual or business?'),
(4, 'auto', 4, 'f_dcode', 'v_255_3', 1, 0, 0, '', 'Dealer Code', '', 'text', '', '8', '', '', '', '', '', 'Dealer tracking code'),
(5, 'auto', 5, 'f_price', 'v_price', 1, 1, 0, 'Range', 'Our Price', '', 'text', '', '15', '', '', 'decimal', '', '', 'Numbers only, no currency symbols'),
(6, 'auto', 6, 'f_stock', 'v_255_4', 1, 0, 0, '', 'Stock #', '', 'text', '', '15', '', '', '', '', '', 'Inventory tracking code'),
(7, 'auto', 7, 'f_msrp', 'v_255_5', 1, 0, 0, '', 'MSRP', '', 'text', '', '10', '', '', '', '', '', 'Manufacturer suggested retail price'),
(8, 'auto', 8, 'f_nada', 'v_255_6', 1, 0, 0, '', 'NADA', '', 'text', '', '15', '', '', '', '', '', 'National Automotive Dealers Association publishes used car pricing and loan information'),
(9, 'auto', 9, 'f_kbb', 'v_255_7', 1, 0, 0, '', 'Kelly Blue Book', '', 'text', '', '10', '', '', '', '', '', 'Kelly Blue Book publishes used car pricing and loan information'),
(10, 'auto', 10, 'f_vin', 'v_255_8', 1, 0, 0, '', 'VIN', '', 'text', '', '20', '', '', '', '', '', '(optional but strongly recommended)'),

(11, 'auto', 11, 'f_year', 'int_1', 1, 0, 0, 'Range', 'Year', '', 'text', '', '6', '4', '4', 'digit', '', '', 'Numbers only'),

(12, 'auto', 12, 'f_make', 'v_255_9', 1, 1, 1, 'Yes', 'Make', '', 'menu', 'Acura\nAlfa Romero\nAM General\nAmerican Motors\nAudi\nBMW\nBuick\nCadillac\nChevrolet\nChrysler\nDaewoo\nDaihatsu\nDMC\nDodge\nEagle\nFerrari\nFord\nGeo\nGMC\nHonda\nHyundai\nInfiniti\nIsuzu\nJaguar\nJeep\nKia\nLamborghini\nLand Rover\nLexus\nLincoln\nLotus\nMaserati\nMazda\nMercedes Benz\nMercury\nMerkur\nMitsubishi\nNissan\nOldsmobile\nPeugot\nPlymouth\nPontiac\nPorsche\nRenault\nRolls Royce\nSaab\nSaturn\nSubaru\nSuzuki\nToyota\nVolkswagen\nVolvo\nYugo', '', '', '', '', '', '', ''),
(13, 'auto', 13, 'f_model', 'v_255_10', 1, 1, 1, 'Yes', 'Model', '', 'text', '', '20', '', '', '', '', '', ''),
(14, 'auto', 14, 'f_descr', 'v_descr', 1, 0, 0, '', 'Description', '', 'htmlarea', '', '40x6', '', '', '', '', '', ''),

(15, 'auto', 15, 'f_mileage', 'int_2', 1, 0, 0, 'Range', 'Mileage', '', 'text', '', '10', '', '', 'digit', '', '', 'Numbers only'),

(16, 'auto', 16, 'f_trans', 'v_255_11', 1, 0, 0, 'Multi', 'Trans', '', 'menu', 'Automatic\n3 speed\n4 speed\n5 speed\n6 speed\nOther', '', '', '', '', '', '', ''),
(17, 'auto', 17, 'f_engine', 'v_255_12', 1, 0, 0, 'Yes', 'Engine', '', 'text', '', '15', '', '', '', '', '', ''),
(18, 'auto', 18, 'f_drivetrain', 'v_255_13', 1, 0, 0, 'Multi', 'Drivetrain', '', 'menu', '2WD\n4WD\n4x2\nAWD\nFWD\nRWD', '', '', '', '', '', '', ''),
(19, 'auto', 19, 'f_bodystyle', 'v_255_14', 1, 0, 0, 'Yes', 'Body Style', '', 'menu', '2-door\n3-door\n4-door\nConvertible\nCrew Cab\nDual Sliding Doors\nExt Cab\nHatchback\nStation Wagon', '', '', '', '', '', '', ''),
(20, 'auto', 20, 'f_extcolor', 'v_255_15', 1, 0, 0, '', 'ExtColor', '', 'text', '', '20', '', '', '', '', '', ''),
(21, 'auto', 21, 'f_intcolor', 'v_255_16', 1, 0, 0, '', 'IntColor', '', 'text', '', '20', '', '', '', '', '', ''),
(22, 'auto', 22, 'f_isc', 'v_255_17', 1, 0, 0, '', 'Int Style - Cloth', '', 'checkbox', '', '', '', '', '', '', '', ''),
(23, 'auto', 23, 'f_isl', 'v_255_18', 1, 0, 0, '', 'Int Style - Leather', '', 'checkbox', '', '', '', '', '', '', '', ''),
(24, 'auto', 24, 'f_seating', 'v_255_19', 1, 0, 0, 'Yes', 'Seating', '', 'menu', '2 Passenger\n4 Passenger\n5 Passenger\n7 Passenger\n15 Passenger\nBench Seating\nBucket Seating\nQuad Seating', '', '', '', '', '', '', ''),
(25, 'auto', 25, 'f_wheels', 'v_255_20', 1, 0, 0, 'Yes', 'Wheels', '', 'menu', 'Alloy Wheels\nAluminum Wheels\nChrome Wheels\nCustom Wheels\nStandard Wheels', '', '', '', '', '', '', ''),
(26, 'auto', 26, 'f_tires', 'v_255_21', 1, 0, 0, 'Yes', 'Tires', '', 'menu', 'Whitewall Tires\nAll Season Tires\nRadial Tires\nOff Road Tires\nWide Tires', '', '', '', '', '', '', ''),
(27, 'auto', 27, 'f_roof', 'v_255_22', 1, 0, 0, 'Yes', 'Roof', '', 'menu', 'Flip Up Sunroof\nHard Top\nPower Sunroof\nRemoveable T-Top\nSunroof\nT-Top', '', '', '', '', '', '', ''),
(28, 'auto', 28, 'f_truckbed', 'v_255_23', 1, 0, 0, 'Yes', 'Truck Bed', '', 'menu', 'Dump Bed\nLong Bed\nShort Bed\nStep Side Bed\nRegular Bed', '', '', '', '', '', '', ''),
(29, 'auto', 29, 'f_stereo', 'v_255_24', 1, 0, 0, 'Yes', 'Stereo', '', 'menu', 'Cassette Player\nCompact Disc Player (CD)\nCassette and Compact Disc (CD)\n6 Disc Compact Changer', '', '', '', '', '', '', ''),
(30, 'auto', 30, 'f_features', 'v_255_25', 1, 0, 0, 'Yes', 'Features', '', 'checkboxes', 'Power Steering\nPower Brakes\nPower Windows\nPower Locks\nPower Mirrors\nPower Seat-Driver\nPower Seats - Pass\nAntilock Brakes\nAir Conditioning\nAir - Rear\nCruise Control\nAir Bags - Driver\nAir Bags - Pass\nSecurity System\nRear Defroster\nTilt Wheel\nRear Wipers\nTinted Windows\nRoof Rack\nFog Lamps\nSliding Rear Win\nRunning Boards\nBed Liner\nCustom Bumper\nGrill Guard\nWinch\nOpt Fuel Tank\nTowing Package\nUtility\nUnderbody Hoist\nHydraulic Lift\nRear Spoiler\nPick up Shell\nTachometer\nKeyless Entry\nDigital Clock\nCup Holder\nToolbox\nTrailer Hitch\nDual Rear Wheels\nAM/FM\nCD player\nD.A.B', '2', '', '', '', '', '', ''),
(31, 'auto', 31, 'f_warranty', 'v_255_26', 1, 0, 0, 'Yes', 'Warranty', '', 'menu', '30 days, 1000 mile limited warranty, See Dealership for Details\nAS IS No Warranty\nExtended Warranty is Available - Ask for details\nRemaining Factory Warranty\nWarranty Included - Ask for details', '', '', '', '', '', '', ''),
(32, 'auto', 32, 'f_cp', 'v_255_27', 1, 1, 0, '', 'Contact Person', '', 'text', '', '30', '', '', '', '', '', ''),
(33, 'auto', 33, 'f_postcode', 'v_zip', 1, 1, 0, '', 'Postal Code', '', 'text', '', '10', '', '', '', '', '', ''),
(34, 'auto', 34, 'f_phone', 'v_255_28', 1, 1, 0, '', 'Phone', '', 'text', '', '15', '', '', '', '', '', ''),
(35, 'auto', 35, 'hw_sold', 'hw_sold', 0, 0, 0, 'Yes', 'Sold', '', 'checkbox', '', '', '', '', '', '', '', ''),

(36, 'general', 1, 'f_title', 'v_title', 1, 1, 0, '', 'Title', '', 'text', '', '40', '', '', '', '', '', ''),
(37, 'general', 2, 'f_descr', 'v_descr', 1, 1, 0, '', 'Description', '', 'htmlarea', '', '40x6', '', '', '', '', '', ''),
(38, 'general', 3, 'f_contact', 'v_255_1', 1, 1, 0, '', 'Contact Name', '', 'text', '', '30', '', '', '', '', '', ''),
(39, 'general', 4, 'f_city', 'v_255_2', 1, 1, 0, 'Yes', 'City', '', 'text', '', '20', '', '255', '', '', '', ''),
(40, 'general', 5, 'f_addr', 'v_255_3', 1, 0, 0, '', 'Street Address', '', 'text', '', '30', '', '', '', '', '', ''),
(41, 'general', 6, 'f_postcode', 'v_zip', 1, 1, 0, '', 'Postal Code', '', 'text', '', '10', '', '', '', '', '', ''),
(42, 'general', 7, 'f_phone', 'v_255_4', 1, 0, 0, '', 'Telephone', '', 'text', '', '15', '', '', '', '', '', ''),
(43, 'general', 8, 'f_url', 'v_255_5', 1, 0, 0, '', 'Web Site', '', 'text', '', '35', '', '', 'url', '', '', 'Starting from "http://"'),
(44, 'general', 9, 'hw_sold', 'hw_sold', 0, 0, 0, 'Yes', 'Sold', '', 'checkbox', '', '', '', '', '', '', '', ''),

(45, 'job', 1, 'f_title', 'v_title', 1, 1, 0, '', 'Job Title', '', 'text', '', '30', '', '50', '', '', '', ''),
(46, 'job', 2, 'f_category', 'v_255_1', 1, 1, 0, 'Multi', 'Job Category', '', 'menu', 'Accounting/Auditing\nAdministrative and Support Services\nAdvertising/Marketing/Public Relations\nAerospace/Aviation/Defense\nAgriculture, Forestry, & Fishing\nArchitectural Services\nArts, Entertainment, and Media\nAutomotive/Motor Vehicle/Parts\nBanking\nBiotechnology and Pharmaceutical\nBuilding and Grounds Maintenance\nComputers, Hardware\nComputers, Software\nConstruction, Mining and Trades\nConsulting Services\nConsumer Products\nCustomer Service and Call Center\nEducation, Training, and Library\nEmployment Placement Agencies\nEngineering\nExecutive Management\nFinance/Economics\nFinancial Services\nGovernment and Policy\nHealthcare - Certified Nursing Assistants/Aides\nHealthcare - LPNs & LVNs\nHealthcare - Laboratory/Pathology Services\nHealthcare - Medical & Dental Practitioners\nHealthcare - Medical Records, Health IT & Informatics\nHealthcare - Other\nHealthcare - Pharmacy\nHealthcare - Radiology/Imaging\nHealthcare - Registered Nurses (RNs)\nHealthcare - Social Services/Mental Health\nHealthcare - Support Services\nHealthcare - Therapy/Rehab Services\nHospitality/Tourism\nHuman Resources\nInformation Technology\nInstallation, Maintenance, and Repair\nInsurance\nInternet/E-Commerce\nLaw Enforcement, and Security\nLegal\nManufacturing and Production\nMilitary\nNonprofit\nOil/Gas/Utilities\nOther\nPersonal Care and Service\nPublishing/Printing\nReal Estate\nRestaurant and Food Service\nRetail/Wholesale\nSales\nScience\nSports and Recreation\nSupply Chain/Logistics\nTelecommunications\nTransportation and Warehousing', '', '', '', '', '', '', ''),
(47, 'job', 3, 'f_company', 'v_255_2', 1, 0, 0, 'Yes', 'Company Name', '', 'text', '', '30', '', '', '', '', '', ''),
(48, 'job', 4, 'f_location', 'v_255_3', 1, 1, 0, 'Yes', 'Job Location', '', 'text', '', '40', '', '', '', '', '', ''),
(49, 'job', 5, 'f_salary_range', 'v_255_4', 1, 0, 0, '', 'Salary Range', '', 'text', '', '30', '', '', '', '', '', ''),
(50, 'job', 6, 'f_position', 'v_255_5', 1, 0, 0, 'Yes', 'Position Type', '', 'menu', 'Full Time\nPart Time\nContract', '100', '', '', '', '', '', ''),
(51, 'job', 7, 'f_descr', 'v_descr', 1, 1, 0, '', 'Short Job Description', '', 'text', '', '50', '', '', '', '', '', ''),
(52, 'job', 8, 'f_descr_full', 'text_1', 1, 0, 1, 'Yes', 'Full Job Description', '', 'textarea', '', '40x8', '', '', '', '', '', ''),
(53, 'job', 9, 'f_qualify', 'text_2', 1, 0, 1, 'Yes', 'Qualifications', '', 'textarea', '', '40x5', '', '', '', '', '', '');

INSERT INTO field (idx, fset, weight, id, db_f, active, required, search_k, search, title, value, type, extra, size, min, max, input, chars, err_msg, txt) VALUES
(55, 'personals', 1, 'f_title', 'v_title', 1, 1, 0, '', 'Caption', '', 'text', '', '50', '0', '255', '', '', '', ''),
(56, 'personals', 2, 'f_descr', 'v_descr', 1, 1, 0, '', 'Text of Ad', '', 'htmlarea', '', '40x7', '50', '1000', '', '', '', ''),

(57, 'personals', 3, 'f_marital', 'v_255_1', 1, 1, 0, 'Multi', 'Marital Status', '', 'menu', 'Single\nMarried\nDivorced\nSeparated\nWidowed', '', '', '', '', '', '', ''),
(58, 'personals', 4, 'f_race', 'v_255_2', 1, 1, 0, 'Multi', 'Race/Ethnicity', '', 'menu', 'White\nBlack\nHispanic\nAsian\nNative American\nOther', '', '', '', '', '', '', ''),
(59, 'personals', 5, 'f_body', 'v_255_3', 1, 1, 0, 'Multi', 'Body Type', '', 'menu', 'Slim\nSlimmer than average\nAverage\nLarger than average\nLarge', '', '', '', '', '', '', ''),

(60, 'personals', 6, 'f_age', 'int_1', 1, 1, 0, 'Range', 'Age', '', 'menu', '16\n17\n18\n19\n20\n21\n22\n23\n24\n25\n26\n27\n28\n29\n30\n31\n32\n33\n34\n35\n36\n37\n38\n39\n40\n41\n42\n43\n44\n45\n46\n47\n48\n49\n50\n51\n52\n53\n54\n55\n56\n57\n58\n59\n60\n61\n62\n63\n64\n65\n66\n67\n68\n69\n70', '', '', '', 'digit', '', '', ''),

(61, 'personals', 7, 'f_children', 'v_255_4', 1, 1, 0, 'Yes', 'Have Children?', '', 'menu', 'Yes\nNo', '', '', '', '', '', '', ''),
(62, 'personals', 8, 'f_religion', 'v_255_5', 1, 1, 0, 'Yes', 'Religion', '', 'menu', 'Atheist\nBuddhist\nCatholic\nChristian\nHindu\nJewish\nMuslim\nNone/Agnostic\nOther', '', '', '', '', '', '', ''),

(63, 'personals', 9, 'f_height', 'int_2', 1, 1, 0, 'Range', 'Height', '', 'text', '', '5', '', '', 'digit', '', '', 'Numbers only'),

(64, 'personals', 10, 'f_weight', 'v_255_6', 1, 1, 0, 'Yes', 'Weight', '', 'menu', '80-90\n91-100\n101-110\n111-120\n121-130\n131-140\n141-150\n151-160\n161-170\n171-180\n181-190\n191-200\n201-210\n211-220\n221-230\n231-240\n241-250\n251-260\n261-270\n271-280\n281-290\n291-300\n301-310\n311-320\n321-330\n331-340\n341-350\nNot Listed', '', '', '', '', '', '', ''),
(65, 'personals', 11, 'f_eyes', 'v_255_7', 1, 1, 0, 'Yes', 'Eye Color', '', 'menu', 'Blue\nBrown\nGreen\nGrey\nHazel\nOther', '', '', '', '', '', '', ''),
(66, 'personals', 12, 'f_hair', 'v_255_8', 1, 1, 0, 'Yes', 'Hair Color', '', 'menu', 'Auburn\nBlonde\nBlack\nBrown\nLight Brown\nGrey\nWhite\nOther', '', '', '', '', '', '', ''),
(67, 'personals', 13, 'f_language', 'v_255_9', 1, 1, 0, '', 'Primary Language', '', 'text', '', '20', '', '', '', '', '', ''),
(68, 'personals', 14, 'f_education', 'v_255_10', 1, 1, 0, 'Yes', 'Education', '', 'menu', 'High School\nBachelors\nTertiary (Uni, College, Technical)\nPost Graduate\nMasters\nDoctoral\nMBA\nJD\nMD\nCPA', '', '', '', '', '', '', ''),
(69, 'personals', 15, 'f_profession', 'v_255_11', 1, 1, 0, 'Yes', 'Profession', '', 'menu', 'Accounting\nActivism\nAdministrative Support\nAdvertising\nAerospace\nAir Conditioning\nAirlines\nApartment Management\nArchitecture\nArt\nAutomotive\nAviation\nBanking\nBeauty\nBilingual\nBookkeeping\nBroadcasting\nCare Giving\nClerical\nCollege\nComputer\nConstruction\nCounseling\nCustomer Service\nDecorating\nDental\nDriving\nEducation\nElectronic\nEmergency\nEmployment\nEngineering\nEntertainment\nEnvironmental\nExecutive\nFashion/Apparel\nFinancial\nFood Services\nForestry\nFundraising\nGardening\nGeneral Office\nGraphics\nGrocery\nHealth/Medical\nHome Services\nHospital\nHotel/Motel\nHousekeeping\nHuman Resources\nHVAC\nImport/Export\nInstaller\nInsurance\nInternet\nJanitorial\nLaw Enforcement\nLegal<option>Maintenance\nManagement\nManufacturing\nMarketing\nMechanical\nMedia\nMerchandising\nModeling\nNursing\nNutrition\nPersonnel\nPest Control\nPet Care\nPhotography\nPlumbing\nPrinting\nProperty Management\nPublic Relations\nPublishing\nPurchasing\nQuality Control\nReal Estate\nRecreation\nResearch\nRestaurant\nSales\nScience\nSecurity\nService Occupations\nShipping/Receiving\nSocial Services\nTeaching\nTechnical\nTelecommunications\nTelemarketing\nTelevision\nTextile\nTraining\nTransportation\nTravel\nWarehouse\nWaste Management\nWord Processing\nOther', '', '', '', '', '', '', ''),
(70, 'personals', 16, 'f_income', 'v_255_12', 1, 0, 0, '', 'Annual Income', '', 'menu', 'No answer\nLess than $24,999\n$25,000 to $34,999\n$35,000 to $49,999\n$50,000 to $74,999\n$75,000 to $99,999\n$100,000 to $149,999\nMore than $150,000', '', '', '', '', '', '', ''),
(71, 'personals', 17, 'f_aim', 'v_255_13', 1, 1, 0, 'Yes', 'Aim', '', 'menu', 'Long-term Relationship\nShort-term Relationship\nCasual Date\nActivity Partner\nE-mail pen pal', '', '', '', '', '', '', ''),
(72, 'personals', 18, 'f_smoker', 'v_255_14', 1, 1, 0, 'Yes', 'Smoker?', '', 'menu', 'Yes\nNo', '', '', '', '', '', '', ''),
(73, 'personals', 19, 'f_drinker', 'v_255_15', 1, 1, 0, 'Yes', 'Social Drinker?', '', 'menu', 'Yes\nNo', '', '', '', '', '', '', ''),
(74, 'personals', 20, 'f_interests', 'v_255_16', 1, 0, 0, 'Yes', 'Interests / Hobbies', '', 'checkboxes', 'Arts & Crafts\nCommunity Service\nDancing\nDining\nFamily\nMovies\nMusic\nOutdoor Activities\nPhotography\nReading\nReligion/Spirituality\nSports\nTheater\nTravel', '2', '', '', '', '', '', ''),
(75, 'personals', 21, 'f_url', 'v_255_17', 1, 0, 0, '', 'Your Favorite Web Site', '', 'text', '', '35', '', '', 'url', '', '', 'Starting from "http://"'),
(76, 'personals', 22, 'f_name', 'v_255_18', 1, 1, 0, '', 'Name', '', 'text', '', '20', '', '', '', '', '', ''),
(77, 'personals', 23, 'f_city', 'v_255_19', 1, 1, 0, '', 'City', '', 'text', '', '20', '', '', '', '', '', ''),
(78, 'personals', 24, 'f_postcode', 'v_zip', 1, 1, 0, '', 'Postal Code', '', 'text', '', '10', '', '', '', '', '', ''),
(79, 'personals', 25, 'f_addr', 'v_255_20', 1, 0, 0, '', 'Street Address', '', 'text', '', '30', '', '', '', '', '', ''),
(80, 'personals', 26, 'f_phone', 'v_255_21', 1, 0, 0, '', 'Telephone Number', '', 'text', '', '30', '', '', '', '', '', ''),

(82, 'property', 1, 'f_title', 'v_title', 1, 1, 0, '', 'Title', '', 'text', '', '40', '3', '255', '', '', '', ''),
(83, 'property', 2, 'f_descr', 'v_descr', 1, 1, 0, '', 'Description', '', 'htmlarea', '', '40x6', '', '', '', '', '', ''),
(84, 'property', 3, 'f_mls', 'v_255_1', 1, 0, 0, 'Yes', 'MLS #', '', 'text', '', '30', '', '100', 'alpha', ' -', '', ''),
(85, 'property', 4, 'f_sale_rent', 'v_255_2', 1, 1, 0, 'Yes', 'For Sale or Rent', '', 'menu', 'FOR RENT\nFOR SALE', '', '', '', '', '', '', ''),
(86, 'property', 5, 'f_price', 'v_price', 1, 1, 0, 'Range', 'Price or Monthly Rent', '', 'text', '', '10', '', '', 'decimal', '', '', 'Numbers only, no currency symbols'),
(87, 'property', 6, 'f_type', 'v_255_3', 1, 1, 0, 'Multi', 'Type', '', 'menu', 'Acreage\nApartment\nCondo\nDuplex\nFarm or Ranch\nHome\nTownhouse\nLot\nMobile Home\nTriplex\nOther', '', '', '', '', '', '', ''),

(88, 'property', 7, 'f_rooms', 'int_1', 1, 1, 0, 'Range', 'Bedrooms', '', 'menu', '0\n1\n2\n3\n4\n5\n6\n7\n8\n9', '', '', '', 'digit', '', '', ''),
(89, 'property', 8, 'f_bath', 'int_2', 1, 1, 0, 'Range', 'Bathrooms', '', 'menu', '0\n1\n2\n3\n4\n5\n6\n7\n8\n9', '', '', '', 'digit', '', '', ''),

(90, 'property', 9, 'f_stories', 'v_255_4', 1, 1, 0, 'Yes', 'Stories', '', 'text', '', '10', '', '', '', '', '', ''),
(91, 'property', 10, 'f_square', 'v_255_5', 1, 1, 0, 'Yes', 'Square Feet', '', 'text', '', '10', '', '', '', '', '', ''),
(92, 'property', 11, 'f_lotsize', 'v_255_6', 1, 1, 0, 'Yes', 'Lot Size', '', 'text', '', '10', '', '', '', '', '', ''),
(93, 'property', 12, 'f_age', 'v_255_7', 1, 1, 0, 'No', 'Age of Home', '', 'text', '', '5', '', '', '', '', '', ''),

(94, 'property', 13, 'f_fireplaces', 'int_3', 1, 0, 0, 'Range', 'Fireplaces', '', 'text', '', '6', '', '', 'digit', '', '', 'Numbers only'),

(95, 'property', 14, 'f_benefits', 'v_255_8', 1, 0, 0, 'Yes', 'Benefits', '', 'checkboxes', 'Near School\nNear Transit\nOcean View\nLake View\nMountain View\nOcean Waterfront\nLake Waterfront\nRiver Waterfront', '3', '', '', '', '', '', ''),
(96, 'property', 15, 'f_appliances', 'v_255_9', 1, 0, 0, 'Yes', 'Appliances', '', 'checkboxes', 'Built-in Microwave\nContinuous Clean Oven\nConvection Oven\nDishwasher\nDisposal\nDouble Ovens\nElectric Cooktop\nElectric Oven/Range\nExhaust Fan,Garborator\nGas Cooktop\nIcemaker\nInstant Hot Water Dispenser\nJenn-Aire Stove\nRange Hood\nSmooth Cooktop\nSub-Zero Refrigerator\nTrash Compactor', '2', '', '', '', '', '', ''),
(97, 'property', 16, 'f_advertiser', 'v_255_10', 1, 1, 0, 'Yes', 'Advertiser Type', '', 'menu', 'Owner\nAgent-Broker\nDeveloper-Builder', '', '', '', '', '', '', ''),
(98, 'property', 17, 'f_city', 'v_255_11', 1, 1, 0, 'Yes', 'City', '', 'text', '', '20', '', '255', '', '', '', ''),
(99, 'property', 18, 'f_addr', 'v_255_12', 1, 0, 0, '', 'Street Address', '', 'text', '', '30', '', '', '', '', '', ''),
(100, 'property', 19, 'f_postcode', 'v_zip', 1, 1, 0, '', 'Postal Code', '', 'text', '', '10', '', '', '', '', '', ''),
(101, 'property', 20, 'f_phone', 'v_255_13', 1, 0, 0, '', 'Phone', '', 'text', '', '15', '', '', '', '', '', ''),
(102, 'property', 21, 'f_contact', 'v_255_14', 1, 1, 0, '', 'Contact Person', '', 'text', '', '30', '', '', '', '', '', ''),
(103, 'property', 22, 'f_url', 'v_255_15', 1, 0, 0, '', 'URL', '', 'text', '', '35', '', '', 'url', '', '', 'Starting from "http://"'),
(104, 'property', 23, 'hw_sold', 'hw_sold', 0, 0, 0, 'Yes', 'Sold', '', 'checkbox', '', '', '', '', '', '', '', '');


INSERT INTO field (idx, fset, weight, id, db_f, editable, active, required, search_k, search, title, value, type, extra, size, min, max, input, chars, err_msg, txt) VALUES

(105, '{user_fields}', 1, 'email', 'email', 'R', 1, 1, 0, '', 'E-mail', '', 'text', '', '20', '', '', 'email', '', '', ''),
(106, '{user_fields}', 2, 'username', 'username', '', 1, 1, 0, '', 'Username', '', 'text', '', '20', '3', '25', 'alpha', '', '', ''),
(107, '{user_fields}', 3, 'pwd', 'pwd', '', 1, 1, 0, '', 'Password', '', 'password', '', '20', '3', '20', '', '', '', ''),

(108, '{user_fields}', 4, 'uf_fname', 'v_255_1', '', 1, 1, 0, '', 'First Name', '', 'text', '', '20', '', '', '', '', '', ''),
(109, '{user_fields}', 5, 'uf_lname', 'v_255_2', '', 1, 1, 0, '', 'Last Name', '', 'text', '', '20', '', '', '', '', '', ''),
(110, '{user_fields}', 6, 'uf_company', 'v_255_3', '', 1, 0, 0, '', 'Company Name', '', 'text', '', '20', '', '', '', '', '', ''),
(111, '{user_fields}', 7, 'uf_url', 'v_255_4', '', 1, 0, 0, '', 'Web URL', '', 'text', '', '20', '', '', '', '', '', ''),
(112, '{user_fields}', 8, 'uf_addr', 'v_255_5', '', 1, 0, 0, '', 'Street Address', '', 'text', '', '20', '', '', '', '', '', ''),
(113, '{user_fields}', 9, 'uf_city', 'v_255_6', '', 1, 0, 0, '', 'City', '', 'text', '', '20', '', '', '', '', '', ''),
(114, '{user_fields}', 10, 'uf_state', 'v_255_7', '', 1, 0, 0, '', 'State', '', 'menu', 'Alabama\nAlaska\nArizona\nArkansas\nCalifornia\nColorado\nConnecticut\nDistrict of Columbia\nDelaware\nFlorida\nGeorgia\nHawaii\nIdaho\nIllinois\nIndiana\nIowa\nKansas\nKentucky\nLouisiana\nMaine\nMaryland\nMassachusetts\nMichigan\nMinnesota\nMississippi\nMissouri\nMontana\nNebraska\nNevada\nNew Hampshire\nNew Jersey\nNew Mexico\nNew York\nNorth Carolina\nNorth Dakota\nOhio\nOklahoma\nOregon\nPennsylvania\nRhode Island\nSouth Carolina\nSouth Dakota\nTennessee\nTexas\nUtah\nVermont\nVirginia\nWashington\nWest Virginia\nWisconsin\nWyoming\nAlberta\nBritish Columbia\nManitoba\nNew Brunswick\nNewfoundland\nNorthwest Territories\nNova Scotia\nNunavut\nOntario\nPrince Edward Island\nQuebec\nSaskatchewan\nYukon\nOther', '', '', '', '', '', '', ''),
(115, '{user_fields}', 11, 'uf_zip', 'v_255_8', '', 1, 0, 0, '', 'Zip', '', 'text', '', '20', '', '', '', '', '', ''),
(116, '{user_fields}', 12, 'uf_country', 'v_255_9', '', 1, 0, 0, '', 'Country', '', 'menu', 'United States\nAfghanistan\nAlbania\nAlgeria\nAmerican Samoa\nAndorra\nAngola\nAnguilla\nAntarctica\nAntigua and Barbuda\nArgentina\nArmenia\nAruba\nAustralia\nAustria\nAzerbaijan\nBahamas\nBahrain\nBangladesh\nBarbados\nBelarus\nBelgium\nBelize\nBenin\nBermuda\nBhutan\nBolivia\nBosnia and Herzegowina\nBotswana\nBouvet Island\nBrazil\nBritish Indian Ocean Territory\nBrunei Darussalam\nBulgaria\nBurkina Faso\nBurundi\nCambodia\nCameroon\nCanada\nCape Verde\nCayman Islands\nCentral African Republic\nChad\nChile\nChina\nChristmas Island\nCocos (Keeling) Islands\nColombia\nComoros\nCongo\nCook Islands\nCosta Rica\nCote D\'Ivoire\nCroatia\nCuba\nCyprus\nCzech Republic\nDenmark\nDjibouti\nDominica\nDominican Republic\nEast Timor\nEcuador\nEgypt\nEl Salvador\nEquatorial Guinea\nEritrea\nEstonia\nEthiopia\nFalkland Islands (Malvinas)\nFaroe Islands\nFiji\nFinland\nFrance\nFrance, Metropolitan\nFrench Guiana\nFrench Polynesia\nFrench Southern Territories\nGabon\nGambia\nGeorgia\nGermany\nGhana\nGibraltar\nGreece\nGreenland\nGrenada\nGuadeloupe\nGuam\nGuatemala\nGuinea\nGuinea-bissau\nGuyana\nHaiti\nHeard and Mc Donald Islands\nHonduras\nHong Kong\nHungary\nIceland\nIndia\nIndonesia\nIran\nIraq\nIreland\nIsrael\nItaly\nJamaica\nJapan\nJordan\nKazakhstan\nKenya\nKiribati\nKorea (North)\nKorea (South)\nKuwait\nKyrgyzstan\nLaos\nLatvia\nLebanon\nLesotho\nLiberia\nLibyan Arab Jamahiriya\nLiechtenstein\nLithuania\nLuxembourg\nMacau\nMacedonia\nMadagascar\nMalawi\nMalaysia\nMaldives\nMali\nMalta\nMarshall Islands\nMartinique\nMauritania\nMauritius\nMayotte\nMexico\nMicronesia\nMoldova\nMonaco\nMongolia\nMontserrat\nMorocco\nMozambique\nMyanmar\nNamibia\nNauru\nNepal\nNetherlands\nNetherlands Antilles\nNew Caledonia\nNew Zealand\nNicaragua\nNiger\nNigeria\nNiue\nNorfolk Island\nNorthern Mariana Islands\nNorway\nOman\nPakistan\nPalau\nPanama\nPapua New Guinea\nParaguay\nPeru\nPhilippines\nPitcairn\nPoland\nPortugal\nPuerto Rico\nQatar\nReunion\nRomania\nRussian Federation\nRwanda\nSaint Kitts and Nevis\nSaint Lucia\nSaint Vincent and the Grenadines\nSamoa\nSan Marino\nSao Tome and Principe\nSaudi Arabia\nSenegal\nSeychelles\nSierra Leone\nSingapore\nSlovakia (Slovak Republic)\nSlovenia\nSolomon Islands\nSomalia\nSouth Africa\nSpain\nSri Lanka\nSt. Helena\nSt. Pierre and Miquelon\nSudan\nSuriname\nSvalbard and Jan Mayen Islands\nSwaziland\nSweden\nSwitzerland\nSyrian Arab Republic\nTaiwan, Province of China\nTajikistan\nTanzania\nThailand\nTogo\nTokelau\nTonga\nTrinidad and Tobago\nTunisia\nTurkey\nTurkmenistan\nTurks and Caicos Islands\nTuvalu\nUganda\nUkraine\nUnited Arab Emirates\nUnited Kingdom\nUnited States\nUnited States Minor Outlying Islands\nUruguay\nUzbekistan\nVanuatu\nVatican City State (Holy See)\nVenezuela\nViet Nam\nVirgin Islands (British)\nVirgin Islands (U.S.)\nWallis and Futuna Islands\nWestern Sahara\nYemen\nYugoslavia\nZaire\nZambia\nZimbabwe', '', '', '', '', '', '', ''),
(117, '{user_fields}', 13, 'uf_phone', 'v_255_10', '', 1, 0, 0, '', 'Phone', '', 'text', '', '20', '', '', '', '', '', ''),
(118, '{user_fields}', 14, 'uf_phone2', 'v_255_11', '', 1, 0, 0, '', 'Phone 2', '', 'text', '', '20', '', '', '', '', '', ''),
(119, '{user_fields}', 15, 'uf_fax', 'v_255_12', '', 1, 0, 0, '', 'Fax', '', 'text', '', '20', '', '', '', '', '', ''),
(122, '{user_fields}', 16, 'uf_hear', 'v_255_13', 'H', 1, 0, 0, '', 'How did you hear about us?', '', 'menu', 'Brochure\nEmail\nEvent or Tradeshow\nFriend\nFamily\nMagazine\nNewspapaer\nPostal Mail\nRoadside Billboard\nRadio\nSearch Engine\nTV\nWebsite\nWord of Mouth\nOther', '', '', '', '', '', '', ''),

(123, '{user_fields}', 2001, 'exp_date', 'exp_date', '', 0, 0, 0, '', 'Account Expires', '', 'datetime', '2004,2036', '', '', '', '', '', '', ''),
(124, '{user_fields}', 2002, 'en_exp_modify', 'en_exp_modify', '', 0, 0, 0, '', 'User can update Ads Exp. Date ?', '', 'checkbox', '1', '', '', '', '', '', '', ''),
(125, '{user_fields}', 2003, 'free_ad_used', 'free_ad_used', '', 0, 0, 0, '', 'Free Ad possibility used ?', '', 'checkbox', '1', '', '', '', '', '', '', ''),
(126, '{user_fields}', 2004, 'regdate', 'regdate', '', 0, 0, 0, '', 'Account Created', 'NOW', 'datetime', '2003,2010', '', '', '', '', '', '', ''),
(127, '{user_fields}', 2005, 'reg_ip', 'reg_ip', '', 0, 0, 0, '', 'Registration IP', '', 'hidden', '', '', '', '', '', '', '', ''),
(128, '{user_fields}', 2006, 'hw_ads_max', 'hw_ads_max', '', 0, 0, 0, '', 'Max {items} allowed', '0', 'text', '', '5', '', '5', 'digit', '', '', 'Set 0 to use global value from "General Setup"'),
(129, '{user_fields}', 2007, 'disabled', 'disabled', '', 0, 0, 0, '', 'Disable account login?', '', 'checkbox', '1', '', '', '', '', '', '', ''),
(130, '{user_fields}', 2008, 'lastlogin', 'lastlogin', '', 0, 0, 0, '', 'Last Login Date', '', 'hidden', '', '', '', '', '', '', '', ''),
(131, '{user_fields}', 2009, 'lastlogin_ip', 'lastlogin_ip', '', 0, 0, 0, '', 'Last Login IP', '', 'hidden', '', '', '', '', '', '', '', '');


INSERT INTO category (id,name,pid,fset) VALUES 
(1, 'Antiques & Collectables', 0, 'general'),
(2, 'Art & Artists', 0, 'general'),
(3, 'Books & Magazines', 0, 'general'),
(4, 'Photo & Video', 0, 'general'),
(5, 'Cars & Trucks, Etc.', 0, 'auto'),
(6, 'Clothing & Apparel', 0, 'general'),
(7, 'Computers & Electronics', 0, 'general'),
(8, 'Construction', 0, 'general'),
(9, 'Entertainment', 0, 'general'),
(10, 'Farm & Horses', 0, 'general'),
(11, 'Health & Medical', 0, 'general'),
(12, 'Hobbies & Kids', 0, 'general'),
(13, 'Home & Garden', 0, 'general'),
(14, 'Jewelry & Clocks', 0, 'general'),
(15, 'Jobs & Skills', 0, 'job'),
(16, 'Office & Business', 0, 'general'),
(17, 'Pets & Animals', 0, 'general'),
(18, 'Real Estate', 0, 'property'),
(19, 'Sports & Fitness', 0, 'general'),
(20, 'Announcements', 0, 'general'),
(21, 'Garage Sales', 0, 'general'),
(22, 'Church', 0, 'general'),
(23, 'Workshops', 0, 'general'),
(24, 'American', 5, 'auto'),
(25, 'Foreign', 5, 'auto'),
(26, 'Suv & 4 Wheel Drive', 5, 'auto'),
(27, 'Trucks', 5, 'auto'),
(28, 'Auto Parts', 5, 'auto'),
(29, 'Antiques', 1, 'general'),
(30, 'Ceramic & Pottery', 1, 'general'),
(31, 'Collectables', 1, 'general'),
(32, 'Retro/Vintage', 1, 'general'),
(33, 'Old Furniture', 1, 'general'),
(34, 'Old, Classic & Rare Books', 1, 'general'),
(35, 'Old Photos, Postcards & Paper', 1, 'general'),
(36, 'Old Tools', 1, 'general'),
(37, 'Sports', 1, 'general'),
(38, 'General', 1, 'general'),
(39, 'Services & Stores', 1, 'general'),
(40, 'Trade/Wanted', 1, 'general'),
(41, 'General Art', 2, 'general'),
(42, 'Paintings', 2, 'general'),
(43, 'Rare', 2, 'general'),
(44, 'Modern', 2, 'general'),
(45, 'Craft', 2, 'general'),
(46, 'Primitive', 2, 'general'),
(47, 'Freelance Artists', 2, 'general'),
(48, 'Ceramic & Pottery', 2, 'general'),
(49, 'Sculpture', 2, 'general'),
(50, 'Utilitarian', 2, 'general'),
(51, 'Frames', 2, 'general'),
(52, 'General', 2, 'general'),
(53, 'Services & Stores', 2, 'general'),
(54, 'Trade/Wanted', 2, 'general'),
(55, 'Books', 3, 'general'),
(56, 'Audio Books', 3, 'general'),
(57, 'Magazines', 3, 'general'),
(58, 'Educational', 3, 'general'),
(59, 'Technical', 3, 'general'),
(60, 'How-to', 3, 'general'),
(61, 'General', 3, 'general'),
(62, 'Services & Stores', 3, 'general'),
(63, 'Trade/Wanted', 3, 'general'),
(64, '35mm Cameras', 4, 'general'),
(65, 'Medium Format', 4, 'general'),
(66, 'Darkroom & Books', 4, 'general'),
(67, 'Digital Cameras', 4, 'general'),
(68, 'Video', 4, 'general'),
(69, 'Movie', 4, 'general'),
(70, 'General', 4, 'general'),
(71, 'Services & Stores', 4, 'general'),
(72, 'Trade/Wanted', 4, 'general'),
(73, 'Antique & Classic', 5, 'auto'),
(74, 'ATVs', 5, 'auto'),
(75, 'Campers & Buses', 5, 'auto'),
(76, 'Heavy Hauling', 5, 'auto'),
(77, 'Motorcycle & Mopeds', 5, 'auto'),
(78, 'Race & Rod', 5, 'auto'),
(79, 'Vans', 5, 'auto'),
(80, 'Tires & Wheels', 5, 'auto'),
(81, 'Trailer', 5, 'auto'),
(82, 'Tools', 5, 'auto'),
(83, 'Boats & Trailers', 5, 'auto'),
(84, 'Bicycles', 5, 'auto'),
(85, 'General', 5, 'auto'),
(86, 'Services & Stores', 5, 'auto'),
(87, 'Trade/Wanted', 5, 'auto'),
(88, 'Amc', 24, 'auto'),
(89, 'Buick', 24, 'auto'),
(90, 'Cadillac', 24, 'auto'),
(91, 'Chevrolet', 24, 'auto'),
(92, 'Chrysler', 24, 'auto'),
(93, 'Dodge', 24, 'auto'),
(94, 'Ford', 24, 'auto'),
(95, 'Lincoln Mercury', 24, 'auto'),
(96, 'Plymouth', 24, 'auto'),
(97, 'Pontiac', 24, 'auto'),
(98, 'Eagle', 24, 'auto'),
(99, 'Saturn', 24, 'auto'),
(100, 'Other', 24, 'auto'),
(101, 'Accura', 25, 'auto'),
(102, 'Audi', 25, 'auto'),
(103, 'BMW', 25, 'auto'),
(104, 'Nissan/Datsun', 25, 'auto'),
(105, 'Honda', 25, 'auto'),
(106, 'Hyundai', 25, 'auto'),
(107, 'Mazda', 25, 'auto'),
(108, 'Mercedes', 25, 'auto'),
(109, 'Mitsubishi', 25, 'auto'),
(110, 'Peugeot', 25, 'auto'),
(111, 'Porche', 25, 'auto'),
(112, 'Toyota', 25, 'auto'),
(113, 'Volvo', 25, 'auto'),
(114, 'Volkswagen', 25, 'auto'),
(115, 'Other', 25, 'auto'),
(116, 'Chevrolet', 26, 'auto'),
(117, 'Dodge', 26, 'auto'),
(118, 'Ford', 26, 'auto'),
(119, 'GMC', 26, 'auto'),
(120, 'Land Rover', 26, 'auto'),
(121, 'Jeep', 26, 'auto'),
(122, 'Subaru', 26, 'auto'),
(123, 'Toyota', 26, 'auto'),
(124, 'Nissan', 26, 'auto'),
(125, 'Mazda', 26, 'auto'),
(126, 'Mitsubishi', 26, 'auto'),
(127, 'Isuzu', 26, 'auto'),
(128, 'Other', 26, 'auto'),
(129, 'Chevrolet', 27, 'auto'),
(130, 'Nissan/Datsun', 27, 'auto'),
(131, 'Dodge', 27, 'auto'),
(132, 'Ford', 27, 'auto'),
(133, 'GMC', 27, 'auto'),
(134, 'International', 27, 'auto'),
(135, 'Mazda', 27, 'auto'),
(136, 'Toyota', 27, 'auto'),
(137, 'Other', 27, 'auto'),
(138, 'Body', 28, 'auto'),
(139, 'Carburetors', 28, 'auto'),
(140, 'Electrical', 28, 'auto'),
(141, 'Engines', 28, 'auto'),
(142, 'Interior', 28, 'auto'),
(143, 'Glass', 28, 'auto'),
(144, 'Stereo', 28, 'auto'),
(145, 'Tires & Wheels', 28, 'auto'),
(146, 'Other', 28, 'auto'),
(147, 'Mens', 6, 'general'),
(148, 'Womens', 6, 'general'),
(149, 'Children', 6, 'general'),
(150, 'Wedding & Formal', 6, 'general'),
(151, 'Work Uniforms', 6, 'general'),
(152, 'Sewing/Alteration', 6, 'general'),
(153, 'General', 6, 'general'),
(154, 'Services & Stores', 6, 'general'),
(155, 'Trade/Wanted', 6, 'general'),
(156, 'Macintosh', 7, 'general'),
(157, 'Windows', 7, 'general'),
(158, 'Linux & Other', 7, 'general'),
(159, 'Dvd & Cd', 7, 'general'),
(160, 'Printers', 7, 'general'),
(161, 'Software', 7, 'general'),
(162, 'Games', 7, 'general'),
(163, 'Accessories', 7, 'general'),
(164, 'Internet', 7, 'general'),
(165, 'General', 7, 'general'),
(166, 'Services & Stores', 7, 'general'),
(167, 'Trade/Wanted', 7, 'general'),
(168, 'Air Conditioning', 8, 'general'),
(169, 'Carpentry', 8, 'general'),
(170, 'Building', 8, 'general'),
(171, 'Brick & Stone', 8, 'general'),
(172, 'Dirt Moving', 8, 'general'),
(173, 'Electrical', 8, 'general'),
(174, 'Heating', 8, 'general'),
(175, 'Heavy Equipment', 8, 'general'),
(176, 'Lumber', 8, 'general'),
(177, 'Plumbing', 8, 'general'),
(178, 'Tools Electric', 8, 'general'),
(179, 'Tools Gas', 8, 'general'),
(180, 'Tools Hand', 8, 'general'),
(181, 'Well', 8, 'general'),
(182, 'General', 8, 'general'),
(183, 'Services & Stores', 8, 'general'),
(184, 'Trade/Wanted', 8, 'general'),
(185, 'Televisions & Big Screens', 9, 'general'),
(186, 'DVD Movie players', 9, 'general'),
(187, 'Movies', 9, 'general'),
(188, 'Stereo & Audio', 9, 'general'),
(189, 'Musical Instruments', 9, 'general'),
(190, 'Music, Records, CDs', 9, 'general'),
(191, 'Bands & Groups', 9, 'general'),
(192, 'General', 9, 'general'),
(193, 'Services & Stores', 9, 'general'),
(194, 'Trade/Wanted', 9, 'general'),
(195, 'Farm Equipment', 10, 'general'),
(196, 'Tractors', 10, 'general'),
(197, 'Horse Trailers', 10, 'general'),
(198, 'Horses', 10, 'general'),
(199, 'Training', 10, 'general'),
(200, 'Livestock', 10, 'general'),
(201, 'Hay & Feed', 10, 'general'),
(202, 'Mow, Till & Seed', 10, 'general'),
(203, 'General', 10, 'general'),
(204, 'Services & Stores', 10, 'general'),
(205, 'Trade/Wanted', 10, 'general'),
(206, 'Medical Appliances', 11, 'general'),
(207, 'Wheel Chairs', 11, 'general'),
(208, 'Massage', 11, 'general'),
(209, 'Nutrition', 11, 'general'),
(210, 'Nurses', 11, 'general'),
(211, 'Sitting', 11, 'general'),
(212, 'Organic', 11, 'general'),
(213, 'Healthy Cooking', 11, 'general'),
(214, 'General', 11, 'general'),
(215, 'Services & Stores', 11, 'general'),
(216, 'Trade/Wanted', 11, 'general'),
(217, 'Hobby & Science', 12, 'general'),
(218, 'Games', 12, 'general'),
(219, 'Toys', 12, 'general'),
(220, 'Bicycles', 12, 'general'),
(221, 'Radio Control', 12, 'general'),
(222, 'Go Carts', 12, 'general'),
(223, 'Toddler/Preschool', 12, 'general'),
(224, 'Books', 12, 'general'),
(225, 'Educational', 12, 'general'),
(226, 'General', 12, 'general'),
(227, 'Services & Stores', 12, 'general'),
(228, 'Trade/Wanted', 12, 'general'),
(229, 'Appliances', 13, 'general'),
(230, 'Bedding', 13, 'general'),
(231, 'Cookware', 13, 'general'),
(232, 'Floor', 13, 'general'),
(233, 'Furnishings', 13, 'general'),
(234, 'Garden', 13, 'general'),
(235, 'Kitchen', 13, 'general'),
(236, 'Landscaping', 13, 'general'),
(237, 'Laundry', 13, 'general'),
(238, 'Lawn', 13, 'general'),
(239, 'Mulch & Compost', 13, 'general'),
(240, 'Refrigerator', 13, 'general'),
(241, 'Windows', 13, 'general'),
(242, 'Tools', 13, 'general'),
(243, 'General', 13, 'general'),
(244, 'Services & Stores', 13, 'general'),
(245, 'Trade/Wanted', 13, 'general'),
(246, 'Mens', 14, 'general'),
(247, 'Womens', 14, 'general'),
(248, 'Watches', 14, 'general'),
(249, 'Art/Craft', 14, 'general'),
(250, 'Clocks', 14, 'general'),
(251, 'General', 14, 'general'),
(252, 'Services & Stores', 14, 'general'),
(253, 'Trade/Wanted', 14, 'general'),
(254, 'Accounting/Books', 15, 'job'),
(255, 'Cleaning', 15, 'job'),
(256, 'Construction', 15, 'job'),
(257, 'Creative', 15, 'job'),
(258, 'Enforcement/Security', 15, 'job'),
(259, 'Errands', 15, 'job'),
(260, 'Factory', 15, 'job'),
(261, 'Farm Work', 15, 'job'),
(262, 'Government', 15, 'job'),
(263, 'Labor', 15, 'job'),
(264, 'Lawn & Landscaping', 15, 'job'),
(265, 'Management', 15, 'job'),
(266, 'Marketing', 15, 'job'),
(267, 'Mechanic', 15, 'job'),
(268, 'Medical', 15, 'job'),
(269, 'Moving & Hauling', 15, 'job'),
(270, 'Office', 15, 'job'),
(271, 'Plumbing', 15, 'job'),
(272, 'Technical', 15, 'job'),
(273, 'Sales', 15, 'job'),
(274, 'Secretarial', 15, 'job'),
(275, 'Student for Hire', 15, 'job'),
(276, 'Restaurant', 15, 'job'),
(277, 'Transportation', 15, 'job'),
(278, 'job', 15, 'job'),
(279, 'Services & Stores', 15, 'job'),
(280, 'Trade/Wanted', 15, 'job'),
(281, 'Furniture', 16, 'general'),
(282, 'Office Equipment', 16, 'general'),
(283, 'Consulting', 16, 'general'),
(284, 'Businesses for Sale', 16, 'general'),
(285, 'Business Opportunities', 16, 'general'),
(286, 'General', 16, 'general'),
(287, 'Services & Stores', 16, 'general'),
(288, 'Trade/Wanted', 16, 'general'),
(289, 'Dogs', 17, 'general'),
(290, 'Cats', 17, 'general'),
(291, 'Birds', 17, 'general'),
(292, 'Fish & Reptile', 17, 'general'),
(293, 'Feed', 17, 'general'),
(294, 'Free to Good Home', 17, 'general'),
(295, 'General', 17, 'general'),
(296, 'Services & Stores', 17, 'general'),
(297, 'Trade/Wanted', 17, 'general'),
(298, 'Apartments for Sale', 18, 'property'),
(299, 'Apartments for Rent', 18, 'property'),
(300, 'Auctions', 18, 'property'),
(301, 'Commercial for Sale', 18, 'property'),
(302, 'Commercial for Rent', 18, 'property'),
(303, 'Condos/Time Share', 18, 'property'),
(304, 'Farm & Acreage', 18, 'property'),
(305, 'Houses for Sale', 18, 'property'),
(306, 'Houses for Rent', 18, 'property'),
(307, 'Log Homes', 18, 'property'),
(308, 'Manufactured Homes', 18, 'property'),
(309, 'Vacation Property', 18, 'property'),
(310, 'Storage Rentals', 18, 'property'),
(311, 'Movers', 18, 'property'),
(312, 'Packers', 18, 'property'),
(313, 'Agents', 18, 'property'),
(314, 'Agencies', 18, 'property'),
(315, 'Attorneys', 18, 'property'),
(316, 'Inspection', 18, 'property'),
(317, 'Realty', 18, 'property'),
(318, 'Services & Stores', 18, 'property'),
(319, 'Trade/Wanted', 18, 'property'),
(320, 'Gym', 19, 'general'),
(321, 'Golf', 19, 'general'),
(322, 'Sports Equipment', 19, 'general'),
(323, 'General', 19, 'general'),
(324, 'Services & Stores', 19, 'general'),
(325, 'Trade/Wanted', 19, 'general'),
(326, 'Personals', 0, 'personals');
